changeset 17910:805a8eab2969

signal_h: Fix Android build * lib/signal.in.h: Add Android to the list of platforms that declare pthread_sigmask() in <pthread.h> instead of <signal.h>.
author Kevin Cernekee <cernekee@google.com>
date Wed, 11 Feb 2015 15:22:57 -0800
parents 1442f927aea4
children 05a21d5b996b
files ChangeLog lib/signal.in.h
diffstat 2 files changed, 9 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Wed Feb 11 15:22:56 2015 -0800
+++ b/ChangeLog	Wed Feb 11 15:22:57 2015 -0800
@@ -56,6 +56,10 @@
 	* m4/net_if_h.m4: Check to make sure <net/if.h> actually defines
 	struct if_nameindex.  If not, enable the replacement header.
 
+	signal_h: Fix Android build
+	* lib/signal.in.h: Add Android to the list of platforms that declare
+	pthread_sigmask() in <pthread.h> instead of <signal.h>.
+
 2015-02-08  Daiki Ueno  <ueno@gnu.org>
 
 	uniname/unimame-tests: don't link with -lunistring
--- a/lib/signal.in.h	Wed Feb 11 15:22:56 2015 -0800
+++ b/lib/signal.in.h	Wed Feb 11 15:22:57 2015 -0800
@@ -55,11 +55,13 @@
 #ifndef _@GUARD_PREFIX@_SIGNAL_H
 #define _@GUARD_PREFIX@_SIGNAL_H
 
-/* Mac OS X 10.3, FreeBSD 6.4, OpenBSD 3.8, OSF/1 4.0, Solaris 2.6 declare
-   pthread_sigmask in <pthread.h>, not in <signal.h>.
+/* Mac OS X 10.3, FreeBSD 6.4, OpenBSD 3.8, OSF/1 4.0, Solaris 2.6, Android
+   declare pthread_sigmask in <pthread.h>, not in <signal.h>.
    But avoid namespace pollution on glibc systems.*/
 #if (@GNULIB_PTHREAD_SIGMASK@ || defined GNULIB_POSIXCHECK) \
-    && ((defined __APPLE__ && defined __MACH__) || defined __FreeBSD__ || defined __OpenBSD__ || defined __osf__ || defined __sun) \
+    && ((defined __APPLE__ && defined __MACH__) \
+        || defined __FreeBSD__ || defined __OpenBSD__ || defined __osf__ \
+        || defined __sun || defined __ANDROID__) \
     && ! defined __GLIBC__
 # include <pthread.h>
 #endif